#!/bin/bash

# specify a directory of virome outputs generated by EsViritu
# the script will make a reactable to browse all the samples in the directory


DIRECTORY1=$1
OUTNAME=$2
SCRIPT_DIR=$( cd -- "$( dirname -- "${BASH_SOURCE[0]}" )" &> /dev/null && pwd )

TAX_TABLES=$( find ${DIRECTORY1}/ -maxdepth 1 -type f -name "*.detected_virus.info.tsv" )

if [ -n "$TAX_TABLES" ] ; then
	echo "found tax tables. combining."
	FIRST_TAX=$( echo "$TAX_TABLES" | head -n1 )
	head -n1 $FIRST_TAX > ${OUTNAME}.detected_virus.combined.tax.tsv
	for TAX in $TAX_TABLES ; do 
		tail -n+2 $TAX  
	done >> ${OUTNAME}.detected_virus.combined.tax.tsv

else
	echo "tables with taxonomy info not found"
	echo "exiting"
	exit
fi

COV_TABLES=$( find ${DIRECTORY1}/ -maxdepth 1 -type f -name "*.100windows.mean_cov.tsv" )

if [ -n "$COV_TABLES" ] ; then
	echo "found coverage tables. combining."
	for COV in $COV_TABLES ; do
		SAMP_P=$( echo $COV | sed 's/.100windows.mean_cov.tsv//g ; s/.*\///g' ) ; 
		awk -v sampq="$SAMP_P" '{OFS=FS="\t"}{print sampq, $0}' $COV
	done > ${OUTNAME}.combined.mean_cov.tsv
else
	echo "tables with coverage not found"
	echo "exiting"
	exit
fi

if [ -s ${OUTNAME}.detected_virus.combined.tax.tsv ] && [ -s ${OUTNAME}.combined.mean_cov.tsv ] ; then
	echo "found combined tax tables and combined coverage tables. making reactable."
	Rscript ${SCRIPT_DIR}/make_reactable_batch_of_samples1.R ${OUTNAME}.combined.mean_cov.tsv ${OUTNAME}.detected_virus.combined.tax.tsv ${OUTNAME}
fi
